@@ -1,7 +1,7 @@
 /*
  * Copyright (C) 2002 Jean-Baptiste Mardelle <bj@altern.org>
  * Copyright (C) 2007 Jimmy Gilles <jimmygilles@gmail.com>
- * Copyright (C) 2008,2009,2010,2011 Rolf Eike Beer <kde@opensource.sf-tec.de>
+ * Copyright (C) 2008,2009,2010,2011,2012 Rolf Eike Beer <kde@opensource.sf-tec.de>
  * Copyright (C) 2011 Philip Greggory Lee <rocketman768@gmail.com>
  */
 
@@ -16,33 +16,31 @@
 
 #include "keyinfodialog.h"
 
-#include <QGridLayout>
-#include <QHBoxLayout>
-#include <QVBoxLayout>
-#include <QFormLayout>
-#include <QGroupBox>
-#include <QCheckBox>
-#include <QPixmap>
-#include <QImage>
-#include <QApplication>
-
-#include <KToolInvocation>
-#include <KPassivePopup>
-#include <KPushButton>
-#include <KDatePicker>
-#include <KMessageBox>
-#include <KUrlLabel>
-#include <KComboBox>
-#include <KLocale>
-
-#include "kgpgkey.h"
-#include "convert.h"
-#include "images.h"
 #include "kgpgchangekey.h"
-#include "kgpgchangepass.h"
-#include "kgpgitemnode.h"
-#include "kgpgitemmodel.h"
 #include "selectexpirydate.h"
+#include "core/convert.h"
+#include "core/images.h"
+#include "core/kgpgkey.h"
+#include "model/kgpgitemmodel.h"
+#include "model/kgpgitemnode.h"
+#include "transactions/kgpgchangepass.h"
+
+#include <KComboBox>
+#include <KDatePicker>
+#include <KLocale>
+#include <KMessageBox>
+#include <KPushButton>
+#include <KToolInvocation>
+#include <KUrlLabel>
+#include <QApplication>
+#include <QCheckBox>
+#include <QFormLayout>
+#include <QGridLayout>
+#include <QGroupBox>
+#include <QHBoxLayout>
+#include <QImage>
+#include <QPixmap>
+#include <QVBoxLayout>
 
 using namespace KgpgCore;
 
@@ -298,9 +296,13 @@ void KgpgKeyInfo::slotChangePass()
 
 void KgpgKeyInfo::slotInfoPasswordChanged(int result)
 {
+	sender()->deleteLater();
+
+	QApplication::restoreOverrideCursor();
+
 	switch (result) {
 	case KGpgTransaction::TS_OK:
-		KPassivePopup::message(i18n("Passphrase for the key was changed"), QString(), Images::kgpg(), this);
+		KMessageBox::information(this, i18n("Passphrase for the key was changed"));
 		break;
 	case KGpgTransaction::TS_BAD_PASSPHRASE:
 		KMessageBox::error(this, i18n("Bad old passphrase, the passphrase for the key was not changed"), i18n("Could not change passphrase"));
@@ -308,10 +310,8 @@ void KgpgKeyInfo::slotInfoPasswordChanged(int result)
 	case KGpgTransaction::TS_USER_ABORTED:
 		break;
 	default:
-		KMessageBox::error(this, i18n("KGpg was unable to change the passphrase.<br />Please see the detailed log for more information."));
+		KMessageBox::error(this, i18n("KGpg was unable to change the passphrase."));
 	}
-
-	QApplication::restoreOverrideCursor();
 }
 
 void KgpgKeyInfo::slotChangeTrust(const int &newtrust)
