@@ -17,22 +17,22 @@
 
 #include "kgpg.h"
 
-#include <QApplication>
-#include <QtDBus/QtDBus>
+#include "gpgproc.h"
+#include "kgpgsettings.h"
+#include "keysmanager.h"
+#include "kgpg_interface.h"
+#include "kgpgexternalactions.h"
+#include "kgpginterface.h"
+#include "core/images.h"
+#include "editor/kgpgeditor.h"
+#include "transactions/kgpgimport.h"
 
 #include <KCmdLineArgs>
 #include <KMessageBox>
 #include <KWindowSystem>
 #include <KMimeType>
-
-#include "images.h"
-#include "kgpgeditor.h"
-#include "kgpgsettings.h"   // automatically created by compilation
-#include "keysmanager.h"
-#include "kgpg_interface.h"
-#include "kgpgexternalactions.h"
-#include "kgpgimport.h"
-#include "kgpginterface.h"
+#include <QApplication>
+#include <QtDBus/QtDBus>
 
 using namespace KgpgCore;
 
@@ -73,7 +73,7 @@ int KGpgApp::newInstance()
 
 		const QString gpgPath(KGpgSettings::gpgConfigPath());
 
-		const QString gpgError = KgpgInterface::getGpgStartupError(KGpgSettings::gpgBinaryPath());
+		const QString gpgError = GPGProc::getGpgStartupError(KGpgSettings::gpgBinaryPath());
 		if (!gpgError.isEmpty()) {
 			KMessageBox::detailedError(0, i18n("GnuPG failed to start.<br />You must fix the GnuPG error first before running KGpg."), gpgError, i18n("GnuPG error"));
 			KApplication::quit();
@@ -82,10 +82,9 @@ int KGpgApp::newInstance()
 		s_keyManager = new KeysManager();
 
 		w = new KGpgExternalActions(s_keyManager, s_keyManager->getModel());
-		connect(w, SIGNAL(importDrop(QString)), s_keyManager, SLOT(slotImport(QString)));
 
-		connect(s_keyManager, SIGNAL(encryptFiles(KUrl::List)), w, SLOT(encryptFiles(KUrl::List)));
-		connect(s_keyManager->s_kgpgEditor, SIGNAL(encryptFiles(KUrl::List)), w, SLOT(encryptFiles(KUrl::List)));
+		connect(s_keyManager, SIGNAL(encryptFiles(KUrl::List)), w, SLOT(slotEncryptDroppedFiles(KUrl::List)));
+		connect(s_keyManager->s_kgpgEditor, SIGNAL(encryptFiles(KUrl::List)), w, SLOT(slotEncryptDroppedFiles(KUrl::List)));
 
 		connect(s_keyManager, SIGNAL(readAgainOptions()), w, SLOT(readOptions()));
 		connect(w, SIGNAL(updateDefault(QString)), SLOT(assistantOver(QString)));
@@ -118,44 +117,41 @@ int KGpgApp::newInstance()
 		if (urlList.empty())
 			return 0;
 
-		w->droppedUrl = urlList.first();
-
 		bool directoryInside = false;
-		const QStringList lst = urlList.toStringList();
-		for (QStringList::const_iterator it = lst.begin(); it != lst.end(); ++it)
-			if (KMimeType::findByUrl(KUrl(*it))->name() == QLatin1String( "inode/directory" ))
+		foreach (const KUrl &url, urlList)
+			if (KMimeType::findByUrl(url)->name() == QLatin1String( "inode/directory" )) {
 				directoryInside = true;
-
-		w->droppedUrls = urlList;
+				break;
+			}
 
 		if (args->isSet("e")) {
 			if (!directoryInside)
-				w->encryptDroppedFile();
+				w->slotEncryptDroppedFiles(urlList);
 			else
-				w->encryptDroppedFolder();
+				w->encryptDroppedFolders(urlList);
 		} else if (args->isSet("s")) {
 			if (!directoryInside)
-				w->showDroppedFile();
+				w->showDroppedFile(urlList.first());
 			else
 				KMessageBox::sorry(0, i18n("Cannot decrypt and show folder."));
 		} else if (args->isSet("S")) {
 			if (!directoryInside)
-				w->signDroppedFile();
+				w->signDroppedFiles(urlList);
 			else
 				KMessageBox::sorry(0, i18n("Cannot sign folder."));
 		} else if (args->isSet("V") != 0) {
 			if (!directoryInside)
-				w->slotVerifyFile();
+				w->verifyFile(urlList.first());
 			else
 				KMessageBox::sorry(0, i18n("Cannot verify folder."));
 		} else {
-			if (directoryInside && (lst.count() > 1)) {
+			if (directoryInside && (urlList.count() > 1)) {
 				KMessageBox::sorry(0, i18n("Unable to perform requested operation.\nPlease select only one folder, or several files, but do not mix files and folders."));
 				return 0;
 			}
 
-			if (w->droppedUrl.fileName().endsWith(QLatin1String(".sig"))) {
-				w->slotVerifyFile();
+			if (urlList.first().fileName().endsWith(QLatin1String(".sig"))) {
+				w->verifyFile(urlList.first());
 			} else {
 				bool haskeys = false;
 				bool hastext = false;
@@ -175,7 +171,7 @@ int KGpgApp::newInstance()
 				}
 
 				if (hastext)
-					w->decryptDroppedFile();
+					w->decryptDroppedFiles(urlList);
 				else
 					s_keyManager->slotImport(urlList);
 			}
