@@ -102,7 +102,7 @@ private slots:
     void slotDelKeyServer();
     void slotEditKeyServer();
     void slotEditKeyServer(QListWidgetItem *);
-    void slotEnableDeleteServer();
+    void slotChangeKeyServerButtonEnable();
     void slotDefaultKeyServer();
     void updateWidgets();
     void updateWidgetsDefault();
